#!/bin/bash

: ${DIALOG=dialog}

CDTITLE="NuOnce Networks, Inc. Presents - Network Reconfigure"
TITLE="Network Setup Utility"


IPADDRESS=`cat /etc/sysconfig/network-scripts/ifcfg-eth0  | /bin/grep IPADDR | /bin/cut -f2 -d=`
NETMASK=`cat /etc/sysconfig/network-scripts/ifcfg-eth0  | /bin/grep NETMASK | /bin/cut -f2 -d=`
DEFAULTGW=`cat /etc/sysconfig/network | /bin/grep GATEWAY | /bin/cut -f2 -d=`

function GetIP() {
MSG="Please Enter your IP Address\n\n"
exec 3>&1
IPADDRESS="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $IPADDRESS 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function GetNM() {
MSG="Please Enter your Netmask\n\n"
exec 3>&1
NETMASK="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $NETMASK 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function GetGW() {
MSG="Please Enter your Default Gateway\n\n"
exec 3>&1
DEFAULTGW="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $DEFAULTGW 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function Confirm() {
MSG="
Please Confirm your Network Settings\n\n
IP Address : $IPADDRESS\n
Netmask    : $NETMASK\n
Gateway    : $DEFAULTGW\n
\n\n
Accept?"
$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE" \
  --yesno "$MSG" 0 0
NO=$?
}

NO=1

GetIP
GetNM
GetGW
Confirm
if [ "$IPADDRESS" == "" ]; then NO=1; fi
if [ "$NETMASK" == "" ]; then NO=1; fi
if [ "$DEFAULTGW" == "" ]; then NO=1; fi

if [ "$NO" == "0" ]; then

  # Change the default gateway
  /usr/bin/perl -pi -e "s#GATEWAY=.*#GATEWAY=$DEFAULTGW#" /etc/sysconfig/network

  # Find the Network ID & Broadcast ID
  NETWORKID=`/usr/bin/minicalc.pl id $IPADDRESS $NETMASK`
  BROADCAST=`/usr/bin/minicalc.pl bid $IPADDRESS $NETMASK`

  # Configure up the init scripts for eth0 properly.
  /bin/echo "DEVICE=eth0" > /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "BOOTPROTO=none" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "ONBOOT=yes" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "BROADCAST=$BROADCAST" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "NETWORK=$NETWORKID" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "NETMASK=$NETMASK" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "IPADDR=$IPADDRESS" >> /etc/sysconfig/network-scripts/ifcfg-eth0
  /bin/echo "USERCTL=no" >> /etc/sysconfig/network-scripts/ifcfg-eth0

  # Convince Sausalito that we are using eth0 & have proper IP info already
  /bin/echo -n $IPADDRESS > /usr/sausalito/codb/objects/2/.ipaddr 
  /bin/echo -n $NETMASK >   /usr/sausalito/codb/objects/2/.netmask
  /bin/echo -n $DEFAULTGW > /usr/sausalito/codb/objects/1/.gateway
  /bin/echo -n "eth0" >     /usr/sausalito/codb/objects/2/.device

  # restart daemons
  echo "Restarting Daemons ... "
  services="network cced.init httpd admserv xinetd sendmail mysqld"
  for service in $services; do
    /sbin/chkconfig $service on > /dev/null 2>&1
    /sbin/service $service restart > /dev/null 2>&1
  done

fi
