#!/bin/bash
# Author: Brian N. Smith
# Copyright 2005, NuOnce Networks.  All rights reserved.
# $Id: finish_install.sh,v 1.00 2005/09/28 8:55:00 bsmith Exp $

# Fix all "tmp" directories to point to /tmp
/bin/rm -Rf /var/tmp >/dev/null 2>&1
/bin/rm -Rf /home/tmp >/dev/null 2>&1
/bin/ln -s /tmp /var/tmp >/dev/null 2>&1
/bin/ln -s /tmp /home/tmp >/dev/null 2>&1

# Add some aliases, and fix the ones on the box
/bin/echo "alias rm=\"rm -f\"" >> /etc/profile
/bin/echo "alias lsd=\"ls -ld */\"" >> /etc/profile
/bin/echo "alias pico=\"pico -w\"" >> /etc/profile
/bin/echo "# Source global definitions" > /root/.bashrc
/bin/echo "if [ -f /etc/bashrc ]; then" >> /root/.bashrc
/bin/echo "        . /etc/bashrc" >> /root/.bashrc
/bin/echo "fi" >> /root/.bashrc

# Change MAIL environment variable
/usr/bin/perl -pi -e 's/MAIL=.*/MAIL=\"\$HOME\/mbox\"/' /etc/profile

# Tell people how to reconfigure network via the CLI
#/bin/echo "/bin/echo \"\"" >> /root/.bashrc
#/bin/echo "/bin/echo \"To change your network settings from the command line, run\"" >> /root/.bashrc
#/bin/echo "/bin/echo \"the command /root/network_settings.sh\"" >> /root/.bashrc
#/bin/echo "/bin/echo \"\"" >> /root/.bashrc
#/bin/echo "/bin/echo \"To remove this notice, edit /root/.bashrc\"" >> /root/.bashrc
#/bin/echo "/bin/echo \"\"" >> /root/.bashrc

# Fix a bug.  This stops HTTP from crashing when you change the DNS server name
/bin/cat /usr/sausalito/handlers/base/apache/reload.pl > /usr/sausalito/handlers/base/apache/restart_httpd.pl

# Fix a small networking problem.  If you don't enable this, you get route for 169.254/16 network
echo "NOZEROCONF=yes" >> /etc/sysconfig/network

# Turn off IPV6
/bin/echo "alias net-pf-10 off" >> /etc/modprobe.conf

# Fix the inittab.  A new copy has been brought over
/bin/chmod 644 /etc/inittab
/bin/chown root:root /etc/inittab

# Install the GPG Key for RPM
/bin/rpm --import /tmp/RPM-GPG-KEY

# Allow logins via the serial interface for root
/bin/echo "ttyS0" >> /etc/securetty

# Change MySQL database store to /home
/bin/rm -Rf /var/lib/mysql >/dev/null 2>&1
/bin/mkdir -p /home/mysql
/bin/ln -s /home/mysql/ /var/lib/mysql
/usr/bin/mysql_install_db >/dev/null 2>&1
/bin/chown mysql:mysql -Rf /home/mysql

# Make cron run out of new "tmp" directory
/usr/bin/perl -pi -e 'if (/HOME/) { print "TMPDIR=/home/.tmp\n"; }' /etc/crontab
/bin/mkdir -p /home/.tmp
/bin/chown root:root /home/.tmp
/bin/chmod 755 /home/.tmp

# Make new pkg install directory, if it doesn't exist!
if [ ! -e /home/.pkg_install_tmp ]; then mkdir -p /home/.pkg_install_tmp; fi

# Disable excuting in shared memory
/usr/bin/perl -pi -e "if (/\/dev\/shm/) { s/defaults/noexec,nosuid,rw/ }" /etc/fstab

# Turn on setup and fix permissions for network setup  
/bin/echo "/tmp/setup.sh" >> /root/.bashrc
/bin/chmod 750 /tmp/setup.sh
/bin/chmod 750 /tmp/PKGS/install.script
/bin/chmod 750 /root/network_settings.sh
/bin/chmod 750 /usr/bin/minicalc.pl

# Make dnsImport.pl +x
/bin/chmod 750 /usr/bin/dnsImport.pl

# Fix execute bits on scripts
/bin/chmod 750 /usr/bin/fix-mysql.sock
/bin/chmod 750 /usr/bin/search

# Point DNS to the local server.  Maybe a bad idea?
/bin/echo "nameserver 127.0.0.1" > /etc/resolv.conf

# Disable some services that do not need to be on
services="smartd autofs irqbalance netfs microcode_ctl mdchk kudzu"
for service in $services; do
  /sbin/chkconfig $service off >/dev/null 2>&1
  /sbin/chkconfig --del $service >/dev/null 2>&1       
done

# Allow LILO to show output to console port
if [ -e /etc/lilo.conf ]; then
  /bin/mv /etc/lilo.conf /etc/lilo.conf.back
  /bin/cat /etc/lilo.conf.back | \
    sed -e 's/linear/serial = 0,38400n8\nlinear/' > /etc/lilo.conf
  /bin/rm -f /etc/lilo.conf.back
  /bin/cat /etc/lilo.conf | grep "append" >/dev/null
  if [ $? = 0 ]; then
    /bin/mv /etc/lilo.conf /etc/lilo.conf.back
    /bin/cat /etc/lilo.conf.back | \
      sed -e "s/\"$/ console=tty0 console=ttyS0,38400n8\"/" > /etc/lilo.conf
  else
    /bin/echo "        append=\"console=tty0 console=ttyS0,38400n8\"" >> /etc/lilo.conf
  fi
  /bin/rm -f /etc/lilo.conf.back
  /sbin/lilo
fi

# Allow GRUB To output to the serial console port
if [ -e /etc/grub.conf ]; then
  /usr/bin/perl -pi -e 'if ( /hiddenmenu/ ) { print "serial --unit=0 --speed=38400 --word=8 --parity=no --stop=1\nterminal --timeout=0 serial console\n"; }' /etc/grub.conf
  /usr/bin/perl -pi -e 'if ( /^\s*initrd/ ) { print "\tconsole=tty0 console=ttyS0,38400\n"; }' /etc/grub.conf
fi

# Show login information in the "issue"
/bin/echo "Welcome to your new server ... " > /etc/issue
/bin/echo "  To finish setup, simply login in as \"root\" with password \"admin\"" >> /etc/issue
/bin/echo "" >> /etc/issue

# Fix Zone Transfer Problem. (/usr/sausalito/scripts/initNamed.sh)
# /bin/chmod 770 /var/named/chroot/var/named/

# Lets add symlink for old style dns setup (/usr/sausalito/scripts/initNamed.sh)
# /bin/ln -s /var/named/chroot/var/named /etc/named

# Make it so no errors during initNamed.sh (/usr/sausalito/scripts/initNamed.sh)
/bin/rm -f /etc/named.conf

# Remove strange link
# /bin/rm -f /var/named/chroot/var/named/named

# Allow locate to run
/usr/bin/perl -pi -e "s/DAILY_UPDATE=no/DAILY_UPDATE=yes/" /etc/updatedb.conf

# Fix Admserv & a bunch of errors
/usr/bin/perl -pi -e "if (/^error_reporting/) { s/E_ALL/E_ALL & ~E_NOTICE/ }" /etc/php.ini
/usr/bin/perl -pi -e "if (/^error_reporting/) { s/E_ALL/E_ALL & ~E_NOTICE/ }" /etc/admserv/php.ini

# Disabled / requested
# /usr/bin/perl -pi -e "if (/^log_errors/) { s/On/Off/; }" /etc/admserv/php.ini 

# Lets make the crontab file more like the Cobalt use to be!
/bin/mkdir -p /etc/cron.half-hourly
/bin/mkdir -p /etc/cron.quarter-hourly
/bin/mkdir -p /etc/cron.quarter-daily
echo "04,34 * * * * root run-parts /etc/cron.half-hourly" >> /etc/crontab
echo "03,18,33,48 * * * * root run-parts /etc/cron.quarter-hourly" >> /etc/crontab
echo "05 0,6,12,18 * * * root run-parts /etc/cron.quarter-daily" >> /etc/crontab

# Relaying for your entire network is kind of stupid.  Lets perminatly fix it!
# push @interfaces, $interface;
#/usr/bin/perl -pi -e "s/push/# push/" /usr/sausalito/handlers/base/email/access.pl

# Disable root login for ssh.  Make people choose it instead.
/usr/bin/perl -pi -e "s/#PermitRootLogin yes/PermitRootLogin no/" /etc/ssh/sshd_config 

# Fix "makewhatis" weekly cron problem
/usr/bin/perl -pi -e "if ( /$makewhatis/ ) { s/\-w/\-w \-u/; }" /etc/cron.weekly/00-makewhatis.cron

# Clean up "logrotate" to work better
/usr/bin/perl -pi -e "s/#compress/compress/" /etc/logrotate.conf
/usr/bin/perl -pi -e "s/4/10/" /etc/logrotate.conf

# Allow passwords to be changed via the "passwd" command (/usr/sausalito/scripts/initPam.sh)
# /usr/bin/perl -pi -e "s/pam_unix\.so/pam_pwdb\.so/" /etc/pam.d/system-auth

# Fix Mail Stats.  Not sure what it does yet though
#/bin/touch /etc/mail/statistics

# Change Logwatch detail from low => high .. provides more output
/usr/bin/perl -pi -e "s/Detail = Low/Detail = High/" /etc/log.d/logwatch.conf

# Change how long files in the /tmp can be there from 30 days to 3 days
/usr/bin/perl -pi -e "s#720#72#g" /etc/cron.daily/tmpwatch

# If RAID was enabled, lets set it up!
MD=`/bin/cat /proc/mdstat | /bin/grep ^md | /usr/bin/wc -l`
if [ "$MD" != "0" ]; then
  # Fix RAID!
  /sbin/lsraid -R -p | sed "/^$/d" | grep -v "#" > /etc/raidtab
fi

# Change Sendmail Header
#/bin/cat /etc/mail/fix_sendmail_header.mc >> /etc/mail/sendmail.mc

# Setup SMTP-Auth properly
#/usr/bin/perl -pi -e "if ( /confAUTH_MECHANISMS/ ) { s/^dnl //; }" /etc/mail/sendmail.mc
#/usr/bin/perl -pi -e "s/MECH=shadow/MECH=pam/" /etc/rc.d/init.d/saslauthd
#/sbin/chkconfig --add saslauthd 
#/sbin/chkconfig saslauthd  on

# Change trueBlue to Merlot
/usr/bin/perl -pi -e "s#trueBlue#Merlot#" /usr/sausalito/constructor/base/user/50_addAdmin.pl
/usr/bin/perl -pi -e "s#trueBlue#Merlot#" /usr/sausalito/ui/web/base/user/userAddHandler.php
/usr/bin/perl -pi -e "s#trueBlue#Merlot#" /usr/sausalito/ui/web/base/sitestats/ReportHelper.php
/usr/bin/perl -pi -e "s#trueBlue#Merlot#" /usr/sausalito/ui/web/login.php
/usr/bin/perl -pi -e "s#trueBlue#Merlot#" /usr/sausalito/ui/libPhp/ServerScriptHelper.php

# Disable reverse IDENT & DNS lookups for FTP
#/usr/bin/perl -pi -e "if (/server_arg/) { s/-s/-s -R/; }" /etc/xinetd.d/pop3
#/usr/bin/perl -pi -e 'if (/^# Port 21/) { print "UseReverseDNS\t\toff\n\n" }' /etc/proftpd.conf 
#/usr/bin/perl -pi -e 'if (/TimesGMT/) { print "   IdentLookups\t\t\toff\n"; }' /etc/proftpd.conf

## First, create "new" tmp directory
/bin/mkdir -p /home/.tmp
/bin/chmod 755 /home/.tmp

## Second, determine if they applied the patch manually.
/bin/cat /etc/cron.daily/logrotate | grep "export TMPDIR=/home/.tmp" >/dev/null 2>&1
if [ $? == 1 ]; then
  ## Doesn't look like they made changes.  So, lets make it
  /bin/echo "Apply Logrotate Fix"
  /bin/sed -i -e '/\/usr\/sbin\/logrotate/i export TMPDIR=/home/.tmp\n' \
    -e '/exit 0/i \\nunset TMPDIR\n' /etc/cron.daily/logrotate
else
  echo "Logrotate Fix already applied"
fi

# Clean up time
/bin/rm /root/install.log
/bin/rm /root/install.log.syslog
/bin/rm /root/anaconda-ks.cfg
/bin/rm /var/log/anaconda.log
/bin/rm /var/log/anaconda.syslog
