#!/bin/bash
# Author: Brian N. Smith
# Copyright 2005, NuOnce Networks.  All rights reserved.
# $Id: setup.sh,v 1.00 2006/04/05 22:19:00 bsmith Exp $
trap '' 2

function Welcome() {
WELCOMEMSG="
Welcome to the NuOnce Installer of CentOS/BlueQuartz\n\n
In just a few minutes, your system will be ready to go!  This\n
setup wizard will configure your Network Settings and also\n
install any additional packages included on your CD.\n"
exec 3>&1
RESULT="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE" \
  --msgbox "$WELCOMEMSG" 15 70 2>&1 1>&3`"
retval=$?
exec 3>&-
}

function GetIP() {
MSG="Please Enter your IP Address\n\n"
exec 3>&1
IPADDRESS="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $IPADDRESS 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function GetNM() {
MSG="Please Enter your Netmask\n\n"
exec 3>&1
NETMASK="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $NETMASK 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function GetGW() {
MSG="Please Enter your Default Gateway\n\n"
exec 3>&1
DEFAULTGW="`$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE"  \
  --inputbox "$MSG" 15 70 $DEFAULTGW 2>&1 1>&3`"
retval=$?
exec 3>&-
RESET=0
}

function Confirm() {
MSG="
Please Confirm your Network Settings\n\n
IP Address : $IPADDRESS\n
Netmask    : $NETMASK\n
Gateway    : $DEFAULTGW\n
\n\n
Accept?"
$DIALOG --nocancel --backtitle "$CDTITLE" --title "$TITLE" \
  --yesno "$MSG" 0 0
NO=$?
}

: ${DIALOG=dialog}

CDTITLE="NuOnce Networks, Inc. Presents - CentOS / BlueQuartz Installer v4.6"
TITLE="Quick Setup Utility"
NO=1

MD=`/bin/cat /proc/mdstat | /bin/grep ^md | /usr/bin/wc -l`
if [ "$MD" != "0" ]; then
  # Turn on "mdchk", as I turn it off in the finish script
  /sbin/chkconfig --add mdchk
  /sbin/chkconfig mdchk on
fi

Welcome

while [ "$NO" == "1" ]; do
  GetIP
  GetNM
  GetGW
  Confirm
  if [ "$IPADDRESS" == "" ]; then NO=1; fi
  if [ "$NETMASK" == "" ]; then NO=1; fi
  if [ "$DEFAULTGW" == "" ]; then NO=1; fi
done

# Change the default gateway
/usr/bin/perl -pi -e "s#GATEWAY=.*#GATEWAY=$DEFAULTGW#" /etc/sysconfig/network

# Find the Network ID & Broadcast ID
NETWORKID=`/usr/bin/minicalc.pl id $IPADDRESS $NETMASK`
BROADCAST=`/usr/bin/minicalc.pl bid $IPADDRESS $NETMASK`

# Configure up the init scripts for eth0 properly.
/bin/echo "DEVICE=eth0" > /etc/sysconfig/network-scripts/ifcfg-eth0
/bin/echo "BOOTPROTO=none" >> /etc/sysconfig/network-scripts/ifcfg-eth0
/bin/echo "ONBOOT=yes" >> /etc/sysconfig/network-scripts/ifcfg-eth0
/bin/echo "BROADCAST=$BROADCAST" >> /etc/sysconfig/network-scripts/ifcfg-eth0
/bin/echo "NETWORK=$NETWORKID" >> /etc/sysconfig/network-scripts/ifcfg-eth0
/bin/echo "NETMASK=$NETMASK" >> /etc/sysconfig/network-scripts/ifcfg-eth0
/bin/echo "IPADDR=$IPADDRESS" >> /etc/sysconfig/network-scripts/ifcfg-eth0
/bin/echo "USERCTL=no" >> /etc/sysconfig/network-scripts/ifcfg-eth0

# Convince Sausalito that we are using eth0 & have proper IP info already
/bin/echo -n $IPADDRESS > /usr/sausalito/codb/objects/2/.ipaddr 
/bin/echo -n $NETMASK >   /usr/sausalito/codb/objects/2/.netmask
/bin/echo -n $DEFAULTGW > /usr/sausalito/codb/objects/1/.gateway
/bin/echo -n "eth0" >     /usr/sausalito/codb/objects/2/.device

# Install any additional packages that customers want installed themselves.
if [ -e /tmp/PKGS/install.files ]; then
  /bin/echo ""
  /bin/echo "Installing additional packages, please wait"
  /bin/echo "-------------------------------------------"
  files=`/bin/cat /tmp/PKGS/install.files`
  for entry in $files; do
    /bin/echo -n "Installing $entry  "
    /usr/sausalito/sbin/pkg_prepare.pl -i -R -f /tmp/PKGS/$entry >/dev/null 2>&1
    /bin/echo -n "[ "; /bin/echo -en "\\033[1;36mOK\\033[0;39m"; /bin/echo " ]"
  done
fi

# Run custom install.script from my CD
if [ -e /tmp/PKGS/install.script ]; then
  /bin/chmod +x /tmp/PKGS/install.script
  /tmp/PKGS/install.script
fi

# Remount /tmp to be non-executable!
/usr/bin/perl -pi -e "if (/\/tmp/) { s/defaults/noexec,nosuid,rw/ }" /etc/fstab
/bin/mount -o remount /tmp

# Restart & Turn on network daemons
/bin/echo ""
/bin/echo "Restarting Daemons ... "
/bin/hostname localhost
services="network cced.init httpd admserv xinetd sendmail mysqld named"
for service in $services; do
  /sbin/chkconfig $service on > /dev/null 2>&1
  /sbin/service $service restart > /dev/null 2>&1
done

# Clean up /tmp directory
rm -Rf /tmp/* >/dev/null 2>&1

# Fix /root/README.1ST to show IP Address of Server
MYIPADD=`/sbin/ifconfig eth0 | grep inet| cut -f2 -d:| cut -f1 -d" "`
/usr/bin/perl -pi -e "s/MYIPADDRESS/$MYIPADD/" /root/README.1ST

/usr/bin/perl -pi -e "s/\/tmp\/setup.sh//" /root/.bashrc

/bin/cat /etc/issue.net > /etc/issue

# Add "httpd" to /etc/passwd & /etc/shadow & /etc/group for backwards compatibility
/bin/cat /etc/passwd | /bin/grep apache | /bin/sed -e "s/apache/httpd/" >> /etc/passwd
/bin/cat /etc/shadow | /bin/grep apache | /bin/sed -e "s/apache/httpd/" >> /etc/shadow
/bin/cat /etc/group | /bin/grep apache | /bin/sed -e "s/apache/httpd/" >> /etc/group

# Show people the readme on first boot
$DIALOG --nocancel --clear --backtitle "$CDTITLE" --title "/root/README.1ST" --textbox "/root/README.1ST" 22 77
